@@ -14,7 +14,7 @@ import binascii
 sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
 
 import youtube_dl.FileDownloader
-import youtube_dl.InfoExtractors
+import youtube_dl.extractor
 from youtube_dl.utils import *
 
 DEF_FILE = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'tests.json')
@@ -72,7 +72,7 @@ class TestDownload(unittest.TestCase):
 def generator(test_case):
 
     def test_template(self):
-        ie = youtube_dl.InfoExtractors.get_info_extractor(test_case['name'])
+        ie = youtube_dl.extractor.get_info_extractor(test_case['name'])
         if not ie._WORKING:
             print('Skipping: IE marked as not _WORKING')
             return
@@ -87,7 +87,7 @@ def generator(test_case):
         params.update(test_case.get('params', {}))
 
         fd = FileDownloader(params)
-        for ie in youtube_dl.InfoExtractors.gen_extractors():
+        for ie in youtube_dl.extractor.gen_extractors():
             fd.add_info_extractor(ie)
         finished_hook_called = set()
         def _hook(status):
@@ -125,11 +125,14 @@ def generator(test_case):
                     self.assertEqual(md5_for_file, tc['md5'])
                 with io.open(tc['file'] + '.info.json', encoding='utf-8') as infof:
                     info_dict = json.load(infof)
-                for (info_field, value) in tc.get('info_dict', {}).items():
-                    if isinstance(value, compat_str) and value.startswith('md5:'):
-                        self.assertEqual(value, 'md5:' + md5(info_dict.get(info_field)))
+                for (info_field, expected) in tc.get('info_dict', {}).items():
+                    if isinstance(expected, compat_str) and expected.startswith('md5:'):
+                        self.assertEqual(expected, 'md5:' + md5(info_dict.get(info_field)))
                     else:
-                        self.assertEqual(value, info_dict.get(info_field))
+                        got = info_dict.get(info_field)
+                        self.assertEqual(
+                            expected, got,
+                            u'invalid value for field %s, expected %r, got %r' % (info_field, expected, got))
 
                 # If checkable fields are missing from the test case, print the info_dict
                 test_info_dict = dict((key, value if not isinstance(value, compat_str) or len(value) < 250 else 'md5:' + md5(value))
